==> haskell-cryptohash-sha256-0.11.101.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-sha256.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-sha256
version: 0.11.101.0
id: cryptohash-sha256-0.11.101.0-D9WEwWp52WRAhUFLlHOr2v
key: cryptohash-sha256-0.11.101.0-D9WEwWp52WRAhUFLlHOr2v
license: BSD3
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-sha256
synopsis: Fast, pure and practical SHA-256 implementation
description:
    A practical incremental and one-pass, pure API to
    the [SHA-256 cryptographic hash algorithm](https://en.wikipedia.org/wiki/SHA-2) according
    to [FIPS 180-4](http://dx.doi.org/10.6028/NIST.FIPS.180-4)
    with performance close to the fastest implementations available in other languages.
    .
    The core SHA-256 algorithm is implemented in C and is thus expected
    to be as fast as the standard [sha256sum(1) tool](https://linux.die.net/man/1/sha256sum);
    for instance, on an /Intel Core i7-3770/ at 3.40GHz this implementation can
    compute a SHA-256 hash over 230 MiB of data in under one second.
    (If, instead, you require a pure Haskell implementation and performance is secondary, please refer to the [SHA package](https://hackage.haskell.org/package/SHA).)
    .
    .
    Additionally, this package provides support for
    .
    - HMAC-SHA-256: SHA-256-based [Hashed Message Authentication Codes](https://en.wikipedia.org/wiki/HMAC) (HMAC)
    - HKDF-SHA-256: [HMAC-SHA-256-based Key Derivation Function](https://en.wikipedia.org/wiki/HKDF) (HKDF)
    .
    conforming to [RFC6234](https://tools.ietf.org/html/rfc6234), [RFC4231](https://tools.ietf.org/html/rfc4231), [RFC5869](https://tools.ietf.org/html/rfc5869), et al..
    .
    === Relationship to the @cryptohash@ package and its API
    .
    This package has been originally a fork of @cryptohash-0.11.7@ because the @cryptohash@
    package had been deprecated and so this package continues to satisfy the need for a
    lightweight package providing the SHA-256 hash algorithm without any dependencies on packages
    other than @base@ and @bytestring@. The API exposed by @cryptohash-sha256-0.11.*@'\''s
    "Crypto.Hash.SHA256" module is guaranteed to remain a compatible superset of the API provided
    by the @cryptohash-0.11.7@'\''s module of the same name.
    .
    Consequently, this package is designed to be used as a drop-in replacement for @cryptohash-0.11.7@'\''s
    "Crypto.Hash.SHA256" module, though with
    a [clearly smaller footprint by almost 3 orders of magnitude](https://www.reddit.com/r/haskell/comments/5lxv75/psa_please_use_unique_module_names_when_uploading/dbzegx3/).
category: Data, Cryptography
exposed: True
indefinite: False
exposed-modules:
    Crypto.Hash.SHA256
hidden-modules: Crypto.Hash.SHA256.FFI
abi: b7260fd6d1b304a7034b8ef8eb413144
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cryptohash-sha256-0.11.101.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/cryptohash-sha256-0.11.101.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/cryptohash-sha256-0.11.101.0
hs-libraries: HScryptohash-sha256-0.11.101.0-D9WEwWp52WRAhUFLlHOr2v
depends:
    base-4.10.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-cryptohash-sha256/html/cryptohash-sha256.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-sha256/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-sha256-0.11.101.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-sha256.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-sha256
version: 0.11.101.0
id: cryptohash-sha256-0.11.101.0-CJeFvVNcGiT5bH5InaPROn
key: cryptohash-sha256-0.11.101.0-CJeFvVNcGiT5bH5InaPROn
license: BSD-3-Clause
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-sha256
synopsis: Fast, pure and practical SHA-256 implementation
description:
    A practical incremental and one-pass, pure API to
    the [SHA-256 cryptographic hash algorithm](https://en.wikipedia.org/wiki/SHA-2) according
    to [FIPS 180-4](http://dx.doi.org/10.6028/NIST.FIPS.180-4)
    with performance close to the fastest implementations available in other languages.
    .
    The core SHA-256 algorithm is implemented in C and is thus expected
    to be as fast as the standard [sha256sum(1) tool](https://linux.die.net/man/1/sha256sum);
    for instance, on an /Intel Core i7-3770/ at 3.40GHz this implementation can
    compute a SHA-256 hash over 230 MiB of data in under one second.
    (If, instead, you require a pure Haskell implementation and performance is secondary, please refer to the [SHA package](https://hackage.haskell.org/package/SHA).)
    .
    .
    Additionally, this package provides support for
    .
    - HMAC-SHA-256: SHA-256-based [Hashed Message Authentication Codes](https://en.wikipedia.org/wiki/HMAC) (HMAC)
    - HKDF-SHA-256: [HMAC-SHA-256-based Key Derivation Function](https://en.wikipedia.org/wiki/HKDF) (HKDF)
    .
    conforming to [RFC6234](https://tools.ietf.org/html/rfc6234), [RFC4231](https://tools.ietf.org/html/rfc4231), [RFC5869](https://tools.ietf.org/html/rfc5869), et al..
    .
    === Relationship to the @cryptohash@ package and its API
    .
    This package has been originally a fork of @cryptohash-0.11.7@ because the @cryptohash@
    package had been deprecated and so this package continues to satisfy the need for a
    lightweight package providing the SHA-256 hash algorithm without any dependencies on packages
    other than @base@ and @bytestring@. The API exposed by @cryptohash-sha256-0.11.*@'\''s
    "Crypto.Hash.SHA256" module is guaranteed to remain a compatible superset of the API provided
    by the @cryptohash-0.11.7@'\''s module of the same name.
    .
    Consequently, this package is designed to be used as a drop-in replacement for @cryptohash-0.11.7@'\''s
    "Crypto.Hash.SHA256" module, though with
    a [clearly smaller footprint by almost 3 orders of magnitude](https://www.reddit.com/r/haskell/comments/5lxv75/psa_please_use_unique_module_names_when_uploading/dbzegx3/).
category: Data, Cryptography
abi: 629d00e0e303783e53d17107934382a6
exposed: True
exposed-modules:
    Crypto.Hash.SHA256
hidden-modules: Crypto.Hash.SHA256.FFI
import-dirs: /usr/lib/ghc-8.4.2/site-local/cryptohash-sha256-0.11.101.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/cryptohash-sha256-0.11.101.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/cryptohash-sha256-0.11.101.0
hs-libraries: HScryptohash-sha256-0.11.101.0-CJeFvVNcGiT5bH5InaPROn
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
haddock-interfaces: /usr/share/doc/haskell-cryptohash-sha256/html/cryptohash-sha256.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-sha256/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
